@@ -1,9 +1,12 @@
 package RSS::From::Twitter;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use HTML::Entities;
 use LWP::UserAgent;
@@ -21,10 +24,13 @@ our @EXPORT_OK = qw(
                        get_rss_from_twitter_user
                );
 
-our $VERSION = '0.05'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Convert Twitter page to RSS',
+};
+
 my %common_args = (
     ua => {
         summary     => 'Supply a custom LWP::UserAgent object',
@@ -247,7 +253,7 @@ sub get_rss_from_twitter_user {
 }
 
 1;
-#ABSTRACT: Convert Twitter page to RSS
+# ABSTRACT: Convert Twitter page to RSS
 
 __END__
 
@@ -261,7 +267,7 @@ RSS::From::Twitter - Convert Twitter page to RSS
 
 =head1 VERSION
 
-This document describes version 0.05 of RSS::From::Twitter (from Perl distribution RSS-From-Twitter), released on 2014-08-16.
+This document describes version 0.06 of RSS::From::Twitter (from Perl distribution RSS-From-Twitter), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -272,8 +278,9 @@ This document describes version 0.05 of RSS::From::Twitter (from Perl distributi
 
 =head2 get_rss_from_twitter(%args) -> [status, msg, result, meta]
 
-Convert Twitter page to RSS.
+{en_US Convert Twitter page to RSS}.
 
+{en_US 
 In June 2013, Twitter retired the RSS v1 API (e.g.
 http://search.twitter.com/search.rss?q=blah, etc). However, its replacement, the
 v1.1 API, is not as straightforward to use (e.g. needs auth). This function
@@ -282,6 +289,7 @@ and converts it to RSS. I wrote this because I have other scripts expecting RSS
 input.
 
 Expect breakage from time to time though, as scraping method is rather fragile.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -289,22 +297,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<title> => I<str>
 
-RSS title.
+{en_US RSS title}.
 
 =item * B<ua> => I<obj>
 
-Supply a custom LWP::UserAgent object.
+{en_US Supply a custom LWP::UserAgent object}.
 
+{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
+}
 
 =item * B<url>* => I<str>
 
-URL, e.g. https://twitter.com/foo or file:/test.html.
+{en_US URL, e.g. https://twitter.com/foo or file:/test.html}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -314,15 +322,17 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 get_rss_from_twitter_list(%args) -> [status, msg, result, meta]
 
-Convert Twitter public list page to RSS.
+{en_US Convert Twitter public list page to RSS}.
 
+{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/USERNAME/LISTNAME>.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -330,22 +340,22 @@ Arguments ('*' denotes required arguments):
 
 =item * B<listname>* => I<str>
 
-User's list name.
+{en_US User's list name}.
 
 =item * B<ua> => I<obj>
 
-Supply a custom LWP::UserAgent object.
+{en_US Supply a custom LWP::UserAgent object}.
 
+{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
+}
 
 =item * B<username>* => I<str>
 
-Twitter username.
+{en_US Twitter username}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -355,15 +365,17 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 get_rss_from_twitter_search(%args) -> [status, msg, result, meta]
 
-Convert Twitter search result page to RSS.
+{en_US Convert Twitter search result page to RSS}.
 
+{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/search?q=QUERY>.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -371,18 +383,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<query>* => I<str>
 
-Search query.
+{en_US Search query}.
 
 =item * B<ua> => I<obj>
 
-Supply a custom LWP::UserAgent object.
+{en_US Supply a custom LWP::UserAgent object}.
 
+{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -392,15 +404,17 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 get_rss_from_twitter_user(%args) -> [status, msg, result, meta]
 
-Convert Twitter user main page to RSS.
+{en_US Convert Twitter user main page to RSS}.
 
+{en_US 
 This function calls get_rss_from_twitter() with URL:
 C<https//twitter.com/USERNAME>.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -408,18 +422,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<ua> => I<obj>
 
-Supply a custom LWP::UserAgent object.
+{en_US Supply a custom LWP::UserAgent object}.
 
+{en_US 
 If supplied, will be used instead of the default LWP::UserAgent object.
+}
 
 =item * B<username>* => I<str>
 
-Twitter username.
+{en_US Twitter username}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -429,7 +443,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -437,7 +451,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/RSS-From-T
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-RSS-From-Twitter>.
+Source repository is at L<https://github.com/perlancar/perl-RSS-From-Twitter>.
 
 =head1 BUGS
 
@@ -449,11 +463,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
